@@ -1,7 +1,11 @@
-import urlparse
-import threading
+# This Source Code Form is subject to the terms of the Mozilla Public
+# License, v. 2.0. If a copy of the MPL was not distributed with this file,
+# You can obtain one at http://mozilla.org/MPL/2.0/.
+
 import json
 import subprocess
+import threading
+import urlparse
 
 from mozprocess import ProcessHandler
 
@@ -21,7 +25,7 @@ class ServoTestharnessExecutor(ProcessTestExecutor):
         self.result_data = None
         self.result_flag = threading.Event()
 
-        self.command = [self.binary,
+        self.command = [self.binary, "--cpu", "--hard-fail",
                         urlparse.urljoin(self.http_server_url, test.url)]
 
         if self.debug_args:
@@ -52,7 +56,7 @@ class ServoTestharnessExecutor(ProcessTestExecutor):
 
     def on_output(self, line):
         prefix = "ALERT: RESULT: "
-        line = line.decode("utf8")
+        line = line.decode("utf8", "replace")
         if line.startswith(prefix):
             self.result_data = json.loads(line[len(prefix):])
             self.result_flag.set()
