@@ -11,6 +11,14 @@ import config
 def abs_path(path):
     return os.path.abspath(os.path.expanduser(path))
 
+def url_or_path(path):
+    import urlparse
+
+    parsed = urlparse.urlparse(path)
+    if len(parsed.scheme) > 2:
+        return path
+    else:
+        return abs_path(path)
 
 def slash_prefixed(url):
     if not url.startswith("/"):
@@ -36,8 +44,7 @@ def create_parser(product_choices=None):
         config_data = config.load()
         product_choices = products.products_enabled(config_data)
 
-    parser = argparse.ArgumentParser("web-platform-tests",
-                                     description="Runner for web-platform-tests tests.")
+    parser = argparse.ArgumentParser(description="Runner for web-platform-tests tests.")
     parser.add_argument("--metadata", action="store", type=abs_path, dest="metadata_root",
                         help="Path to the folder containing test metadata"),
     parser.add_argument("--tests", action="store", type=abs_path, dest="tests_root",
@@ -92,6 +99,11 @@ def create_parser(product_choices=None):
     parser.add_argument('--pause-on-unexpected', action="store_true",
                         help="Halt the test runner when an unexpected result is encountered")
 
+    parser.add_argument("--symbols-path", action="store", type=url_or_path,
+                        help="Path or url to symbols file used to analyse crash minidumps.")
+    parser.add_argument("--stackwalk-binary", action="store", type=abs_path,
+                        help="Path to stackwalker program used to analyse minidumps.")
+
     parser.add_argument("--b2g-no-backup", action="store_true", default=False,
                         help="Don't backup device before testrun with --product=b2g")
 
@@ -185,7 +197,7 @@ def create_parser_update():
     parser.add_argument("--no-check-clean", action="store_true", default=False,
                         help="Don't check the working directory is clean before updating")
     parser.add_argument("--patch", action="store_true",
-                        help="Create an mq patch or git branch+commit containing the changes.")
+                        help="Create an mq patch or git commit containing the changes.")
     parser.add_argument("--sync", dest="sync", action="store_true", default=False,
                         help="Sync the tests with the latest from upstream")
     parser.add_argument("--ignore-existing", action="store_true", help="When updating test results only consider results from the logfiles provided, not existing expectations.")
